@@ -31,6 +31,9 @@ export class Component {
   static readonly AWSLAMBDA_FUNCTION = new Component(124);
   static readonly AWSLAMBDA_GATEWAYAPIHTTP = new Component(125);
   static readonly AWSLAMBDA_GATEWAYAPIREST = new Component(126);
+  static readonly AWS_DYNAMODB = new Component(138);
+  static readonly AWS_SNS = new Component(139);
+  static readonly AWS_SQS = new Component(140);
   static readonly EXPRESS = new Component(4002);
   static readonly AXIOS = new Component(4005);
   static readonly MONGOOSE = new Component(4006);
